package com.mdd.admin.validate.system;

import com.mdd.common.validator.annotation.IntegerContains;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.NotNull;
import org.hibernate.validator.constraints.Length;

@ApiModel("系统角色创建参数")
public class SystemRoleCreateValidate implements Serializable {
   private static final long serialVersionUID = 1L;
   @ApiModelProperty(
      value = "角色名称",
      required = true
   )
   private @NotNull(
   message = "缺少参数name"
) @Length(
   min = 1,
   max = 30,
   message = "角色名称必须在1~30个字符内"
) String name;
   @ApiModelProperty(
      value = "备注",
      required = true
   )
   private @Length(
   max = 200,
   message = "备注信息不能超过200个字符"
) String remark;
   @ApiModelProperty(
      value = "排序",
      required = true
   )
   private @DecimalMin(
   value = "0",
   message = "排序号值不能少于0"
) Integer sort = 0;
   @IntegerContains(
      values = {0, 1}
   )
   @ApiModelProperty(
      value = "是否禁用",
      required = true
   )
   private @NotNull(
   message = "请选择状态"
) Integer isDisable;
   @ApiModelProperty("菜单权限")
   private String menuIds = "";

   public @NotNull(
   message = "缺少参数name"
) String getName() {
      return this.name;
   }

   public String getRemark() {
      return this.remark;
   }

   public Integer getSort() {
      return this.sort;
   }

   public @NotNull(
   message = "请选择状态"
) Integer getIsDisable() {
      return this.isDisable;
   }

   public String getMenuIds() {
      return this.menuIds;
   }

   public void setName(@NotNull(
   message = "缺少参数name"
) String name) {
      this.name = name;
   }

   public void setRemark(String remark) {
      this.remark = remark;
   }

   public void setSort(Integer sort) {
      this.sort = sort;
   }

   public void setIsDisable(@NotNull(
   message = "请选择状态"
) Integer isDisable) {
      this.isDisable = isDisable;
   }

   public void setMenuIds(String menuIds) {
      this.menuIds = menuIds;
   }

   public boolean equals(Object o) {
      if (o == this) {
         return true;
      } else if (!(o instanceof SystemRoleCreateValidate)) {
         return false;
      } else {
         SystemRoleCreateValidate other = (SystemRoleCreateValidate)o;
         if (!other.canEqual(this)) {
            return false;
         } else {
            label71: {
               Object this$sort = this.getSort();
               Object other$sort = other.getSort();
               if (this$sort == null) {
                  if (other$sort == null) {
                     break label71;
                  }
               } else if (this$sort.equals(other$sort)) {
                  break label71;
               }

               return false;
            }

            Object this$isDisable = this.getIsDisable();
            Object other$isDisable = other.getIsDisable();
            if (this$isDisable == null) {
               if (other$isDisable != null) {
                  return false;
               }
            } else if (!this$isDisable.equals(other$isDisable)) {
               return false;
            }

            label57: {
               Object this$name = this.getName();
               Object other$name = other.getName();
               if (this$name == null) {
                  if (other$name == null) {
                     break label57;
                  }
               } else if (this$name.equals(other$name)) {
                  break label57;
               }

               return false;
            }

            Object this$remark = this.getRemark();
            Object other$remark = other.getRemark();
            if (this$remark == null) {
               if (other$remark != null) {
                  return false;
               }
            } else if (!this$remark.equals(other$remark)) {
               return false;
            }

            Object this$menuIds = this.getMenuIds();
            Object other$menuIds = other.getMenuIds();
            if (this$menuIds == null) {
               if (other$menuIds == null) {
                  return true;
               }
            } else if (this$menuIds.equals(other$menuIds)) {
               return true;
            }

            return false;
         }
      }
   }

   protected boolean canEqual(Object other) {
      return other instanceof SystemRoleCreateValidate;
   }

   public int hashCode() {
      int PRIME = true;
      int result = 1;
      Object $sort = this.getSort();
      result = result * 59 + ($sort == null ? 43 : $sort.hashCode());
      Object $isDisable = this.getIsDisable();
      result = result * 59 + ($isDisable == null ? 43 : $isDisable.hashCode());
      Object $name = this.getName();
      result = result * 59 + ($name == null ? 43 : $name.hashCode());
      Object $remark = this.getRemark();
      result = result * 59 + ($remark == null ? 43 : $remark.hashCode());
      Object $menuIds = this.getMenuIds();
      result = result * 59 + ($menuIds == null ? 43 : $menuIds.hashCode());
      return result;
   }

   public String toString() {
      return "SystemRoleCreateValidate(name=" + this.getName() + ", remark=" + this.getRemark() + ", sort=" + this.getSort() + ", isDisable=" + this.getIsDisable() + ", menuIds=" + this.getMenuIds() + ")";
   }
}
